package
Version:
v1.3.3
Opens a new window with list of versions in this module.
Published: Jun 23, 2026
License: AGPL-3.0, AGPL-3.0-or-later
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Set struct {
HasIPCmd bool
HasIPTablesCmd bool
HasNetAdmin bool
HasNetRaw bool
HasTUNDevice bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.